%global tzversion tzdata2017b

Name:             joda-time
Version:          2.9.9
Release:          %mkrel 9.%{tzversion}.3
Group:            Development/Java
Summary:          Java date and time API

License:          ASL 2.0
URL:              https://www.joda.org/joda-time/
Source0:          https://github.com/JodaOrg/%{name}/archive/v%{version}.tar.gz
Source1:          ftp://ftp.iana.org/tz/releases/%{tzversion}.tar.gz
BuildArch:        noarch

BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.apache.velocity:velocity)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.joda:joda-convert)


%description
Joda-Time provides a quality replacement for the Java date and time classes. The
design allows for multiple calendar systems, while still providing a simple API.
The 'default' calendar is the ISO8601 standard which is used by XML. The
Gregorian, Julian, Buddhist, Coptic, Ethiopic and Islamic systems are also
included, and we welcome further additions. Supporting classes include time
zone, duration, format and parsing.


%package javadoc
Summary:          Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.


%prep
%setup -q

sed -i 's/\r//' LICENSE.txt
sed -i 's/\r//' NOTICE.txt
sed -i 's/\r//' RELEASE-NOTES.txt

# all java binaries must be removed from the sources
find . -name '*.jar' -exec rm -f '{}' \;

# replace internal tzdata
rm -f src/main/java/org/joda/time/tz/src/*
tar -xzf %{SOURCE1} -C src/main/java/org/joda/time/tz/src/

# compat filename
%mvn_file : %{name}

# javadoc generation fails due to strict doclint in JDK 8
%pom_remove_plugin :maven-javadoc-plugin

%build
# Ignore test failures due to incompatibility with Java 11
%mvn_build -- -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8 -Dmaven.test.failure.ignore=true

%install
%mvn_install

%files -f .mfiles
%doc RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Fri May 24 2024 ns80 <ns80> 2.9.9-9.tzdata2017b.3.mga10
+ Revision: 2067263
- rebuild for java 21

* Sat Mar 26 2022 umeabot <umeabot> 2.9.9-9.tzdata2017b.2.mga9
+ Revision: 1827587
- Mageia 9 Mass Rebuild

* Thu Sep 10 2020 daviddavid <daviddavid> 2.9.9-9.tzdata2017b.1.mga8
+ Revision: 1624122
- Rebuilt for JDK-11
- Fix build against Java 11

* Fri Feb 14 2020 umeabot <umeabot> 2.9.9-3.tzdata2017b.2.mga8
+ Revision: 1520594
- Mageia 8 Mass Rebuild

* Mon Dec 03 2018 daviddavid <daviddavid> 2.9.9-3.tzdata2017b.1.mga7
+ Revision: 1337725
- Update to upstream version 2.9.9 (sync with fc29)
- Update to tzdata2017b

* Tue Sep 18 2018 umeabot <umeabot> 2.9.3-2.tzdata2016c.2.mga7
+ Revision: 1262279
- Mageia 7 Mass Rebuild

* Sun May 21 2017 neoclust <neoclust> 2.9.3-2.tzdata2016c.1.mga6
+ Revision: 1103921
- New version 2.9.3

* Fri Apr 29 2016 daviddavid <daviddavid> 2.9.2-2.tzdata2016a.1.mga6
+ Revision: 1007670
- Reintroduce accidentally removed tzdata version to release tag
+ neoclust <neoclust>
- Second rebuild of the java stack

* Mon Feb 29 2016 daviddavid <daviddavid> 2.9.2-1.mga6
+ Revision: 980785
- Update to upstream version 2.9.2

* Mon Feb 29 2016 daviddavid <daviddavid> 2.9-1.tzdata2015e.1.mga6
+ Revision: 980776
- First rebuild of the java stack
+ neoclust <neoclust>
- sync package joda-time with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.3-0.tzdata2013g.3.mga5
+ Revision: 747184
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 dmorgan <dmorgan> 2.3-0.tzdata2013g.1.mga5
+ Revision: 636339
- New version

* Sun May 18 2014 dmorgan <dmorgan> 2.2-2.tzdata2013c.1.mga5
+ Revision: 623554
- New version

* Sat May 17 2014 dmorgan <dmorgan> 2.1-2.tzdata2012h.5.mga5
+ Revision: 623497
- Enable testsuite
- Update to lates packaging guidelines

* Sun Dec 22 2013 dmorgan <dmorgan> 2.1-2.tzdata2012h.4.mga4
+ Revision: 559945
- Build with maven-local
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.1-2.tzdata2012h.2.mga3
+ Revision: 355513
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 03 2012 dmorgan <dmorgan> 2.1-2.tzdata2012h.1.mga3
+ Revision: 325924
- New version
- Build with maven
- Adapt to new guidelines
- Fix copying SOURCE2
- Fix copying SOURCE2
+ gil <gil>
- add toolchains.xml maven-toolchains-plugin cfg file
- add maven-toolchains-plugin support, removed patch0

* Thu Apr 28 2011 dmorgan <dmorgan> 1.6.2-5.tzdata2011f.2.mga1
+ Revision: 92543
- Rebuild after bootstrapping
- imported package joda-time


* Fri Apr 15 2011 Chris Spike <spike@fedoraproject.org> 1.6.2-5.tzdata2011f
- New tzdata (2011f)
- Fixed build for maven 3
- Cleaned up BRs

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.2-4.tzdata2010n
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Oct 27 2010 Chris Spike <spike@fedoraproject.org> 1.6.2-3.tzdata2010n
- New tzdata (2010n)

* Thu Sep 23 2010 Chris Spike <spike@fedoraproject.org> 1.6.2-2.tzdata2010l
- Ignore test failures (tests fail in koji)

* Thu Sep 23 2010 Chris Spike <spike@fedoraproject.org> 1.6.2-1.tzdata2010l
- New upstream version (1.6.2)
- Removed dependency on main package for -javadoc subpackage
- Replaced summary with latest version
- Switched from ant to maven (no build.xml any more)
- Added patch to remove maven toolchain from pom.xml

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-3.tzdata2008i
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-2.tzdata2008i
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Dec 12 2008 Conrad Meyer <konrad@tylerc.org> - 1.6-1.tzdata2008i
- New upstream version (1.6).

* Fri Oct 31 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-10.tzdata2008i
- New tzdata.

* Mon Oct 13 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-7.tzdata2008g
- New tzdata (2008g).

* Sat Aug 23 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-7.tzdata2008e
- New version with new tzdata (2008e).

* Sat Jul 19 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-7.tzdata2008d
- New version with new tzdata (2008d).

* Mon Jun 9 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-6.tzdata2008c
- New version with new tzdata (2008c).

* Sun Apr 6 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-5.tzdata2008b
- Don't compile GCJ bits yet as we hit some GCJ bug.

* Sat Apr 5 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-4.tzdata2008b
- Update to tzdata2008b.
- Use unversioned jar.
- Some small things to comply with Java Packaging Guidelines.
- GCJ support.

* Mon Mar 17 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-3.tzdata2008a
- Many small changes from bz# 436239 comment 6.
- Change -javadocs to -javadoc in accordance with java packaging
  guidelines draft.

* Sun Mar 16 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-2
- Use system junit via Mamoru Tasaka's patch.

* Mon Mar 3 2008 Conrad Meyer <konrad@tylerc.org> - 1.5.2-1
- Initial package.
